/*-----------------------------------------------------------------------*/
/* Low level disk I/O module SKELETON for FatFs     (C)ChaN, 2019        */
/*-----------------------------------------------------------------------*/
/* If a working storage control module is available, it should be        */
/* attached to the FatFs via a glue function rather than modifying it.   */
/* This is an example of glue functions to attach various exsisting      */
/* storage control modules to the FatFs module with a defined API.       */
/*-----------------------------------------------------------------------*/

#include "ff.h"			/* Obtains integer types */
#include "diskio.h"		/* Declarations of disk functions */

/* Definitions of physical drive number for each drive */



/*-----------------------------------------------------------------------*/
/* Get Drive Status                                                      */
/*-----------------------------------------------------------------------*/

DSTATUS disk_status (
	BYTE pdrv		/* Physical drive nmuber to identify the drive */
)
{
	DSTATUS stat;
	int result;

	if(pdrv >= DEV_SDIO_MIN && pdrv <= DEV_SDIO_MAX){
		
		return 0; // OK
	}

	if(pdrv >= DEV_USB_MIN && pdrv <= DEV_USB_MAX){
		USB_disk_status(pdrv - DEV_USB_MIN);
		return 0; // OK
	}

	return STA_NOINIT;
}



/*-----------------------------------------------------------------------*/
/* Inidialize a Drive                                                    */
/*-----------------------------------------------------------------------*/

DSTATUS disk_initialize (
	BYTE pdrv				/* Physical drive nmuber to identify the drive */
)
{
	DSTATUS stat;
	int result;
	if(pdrv >= DEV_SDIO_MIN && pdrv <= DEV_SDIO_MAX){
		
		return 0; // OK
	}

	if(pdrv >= DEV_USB_MIN && pdrv <= DEV_USB_MAX){
		USB_disk_initialize(pdrv - DEV_USB_MIN);
		return 0; // OK
	}
	return STA_NOINIT;
}



/*-----------------------------------------------------------------------*/
/* Read Sector(s)                                                        */
/*-----------------------------------------------------------------------*/

DRESULT disk_read (
	BYTE pdrv,		/* Physical drive nmuber to identify the drive */
	BYTE *buff,		/* Data buffer to store read data */
	LBA_t sector,	/* Start sector in LBA */
	UINT count		/* Number of sectors to read */
)
{
	DRESULT res;
	int result;

	if(pdrv >= DEV_SDIO_MIN && pdrv <= DEV_SDIO_MAX){
		
		return 0; // OK
	}

	if(pdrv >= DEV_USB_MIN && pdrv <= DEV_USB_MAX){
		USB_disk_read(pdrv - DEV_USB_MIN, buff, sector, count);
		return 0; // OK
	}

	return RES_PARERR;
}



/*-----------------------------------------------------------------------*/
/* Write Sector(s)                                                       */
/*-----------------------------------------------------------------------*/

#if FF_FS_READONLY == 0

DRESULT disk_write (
	BYTE pdrv,			/* Physical drive nmuber to identify the drive */
	const BYTE *buff,	/* Data to be written */
	LBA_t sector,		/* Start sector in LBA */
	UINT count			/* Number of sectors to write */
)
{
	DRESULT res;
	int result;

	if(pdrv >= DEV_SDIO_MIN && pdrv <= DEV_SDIO_MAX){
		
		return 0; // OK
	}

	if(pdrv >= DEV_USB_MIN && pdrv <= DEV_USB_MAX){
		result = USB_disk_write(pdrv - DEV_USB_MIN, buff, sector, count);
		return 0; // OK
	}
	
	return RES_PARERR;
}

#endif


/*-----------------------------------------------------------------------*/
/* Miscellaneous Functions                                               */
/*-----------------------------------------------------------------------*/

DRESULT disk_ioctl (
	BYTE pdrv,		/* Physical drive nmuber (0..) */
	BYTE cmd,		/* Control code */
	void *buff		/* Buffer to send/receive control data */
)
{
	DRESULT res;
	int result;


	if(pdrv >= DEV_SDIO_MIN && pdrv <= DEV_SDIO_MAX){
		
		return 0; // OK
	}

	if(pdrv >= DEV_USB_MIN && pdrv <= DEV_USB_MAX){
		USB_disk_ioctl(pdrv - DEV_USB_MIN, cmd, buff);
		return 0; // OK
	}

	return RES_PARERR;
}

